@@ -57,6 +57,10 @@ class BaseballReferenceScraper:
             if team_match and not self.is_multi_year and not is_full_career:
                 self.team_override = team_id
 
+        # CHECK FOR TYPE OVERRIDE
+        self.pitcher_override = '(PITCHER)' if '(PITCHER)' in self.name.upper() else None
+        self.hitter_override = '(HITTER)' if '(HITTER)' in self.name.upper() else None
+
         # CHECK FOR BASEBALL REFERENCE ID
         self.is_name_a_bref_id = any(char.isdigit() for char in name)
         if self.is_name_a_bref_id:
@@ -204,6 +208,9 @@ class BaseballReferenceScraper:
             # HAND / TYPE
             type = self.type(positional_fielding,year=year)
 
+            # NATIONALITY
+            nationality = self.nationality(soup_for_homepage_stats=soup_for_homepage_stats)
+
             # WAR
             stats_dict.update({'bWAR': self.__bWar(soup_for_homepage_stats, year, type)})
 
@@ -218,6 +225,7 @@ class BaseballReferenceScraper:
             stats_dict['hand_throw'] = self.hand(soup_for_homepage_stats, type='Pitcher') # ALWAYS PASS PITCHER TO STORE THROWING HAND
             stats_dict['name'] = name
             stats_dict['years_played'] = years_played
+            stats_dict['nationality'] = nationality
             
             # HITTING / HITTING AGAINST
             advanced_stats = self.advanced_stats(type,year=year)
@@ -315,7 +323,7 @@ class BaseballReferenceScraper:
                         use_stat_per_yr = True
                     else:
                         today = datetime.today()
-                        card_year_end_date = datetime(int(year), 10, 15)
+                        card_year_end_date = datetime(int(year), 10, 1)
                         is_year_end_date_before_today = today < card_year_end_date
                         drs_is_above_0 = int(drs_rating) > 0 if drs_rating else False
                         use_stat_per_yr = (str(year) == '2020' or is_year_end_date_before_today) and drs_is_above_0
@@ -443,6 +451,35 @@ class BaseballReferenceScraper:
             name_string = name_object.find('span').get_text()
         return name_string
 
+    def nationality(self, soup_for_homepage_stats) -> str:
+        """Parse player's nationality
+
+        Args:
+          soup_for_homepage_stats: BeautifulSoup object with all stats from homepage.
+
+        Raises:
+          ValueError: No player nationality found.
+
+        Returns:
+          'Right', 'Left', or 'Both' string.
+        """
+
+        # FIND METADATA DIV
+        metadata = soup_for_homepage_stats.find('div', attrs = {'id': 'meta'})
+        if metadata is None:
+            raise ValueError('No player nationality found')
+        
+        # FIND ALL CLASSES WITH THE KEYWORD "f-i" IN THE CLASS NAME.
+        #   EX: <span class="f-i f-pr" style="">pr</span>
+        # WHEN A PLAYER HAS 2 NATIONALITIES, CHOSE THE BIRTH COUNTRY
+        for strong_tag in metadata.find_all('span', { "class": re.compile('.*f-i.*') }):
+            country_abbr = strong_tag.text
+            if country_abbr:
+                return country_abbr.upper()
+
+        # NO NATIONALITY WAS FOUND, RETURN NONE
+        return None
+    
     def type(self, positional_fielding, year):
         """Guess Player Type (Pitcher or Hitter) based on games played at each position.
 
@@ -571,18 +608,19 @@ class BaseballReferenceScraper:
                             position = fielding_row['pos_name_short']
                             ooa = fielding_row['outs_above_average']
                             if ooa:
+                                ooa_rounded = round(ooa, 3)
                                 if position in fielding_data.keys():
                                     # POSITION IS ALREADY IN JSON, ADD TO IT
-                                    fielding_data[position] += ooa
+                                    fielding_data[position] += ooa_rounded
                                 else:
-                                    fielding_data[position] = ooa
+                                    fielding_data[position] = ooa_rounded
                                 # IF OF POSITION, ADD TO TOTAL OF DEFENSE
                                 if position in ['LF','CF','RF']:
                                     if 'OF' in fielding_data.keys():
                                         # POSITION IS ALREADY IN JSON, ADD TO IT
-                                        fielding_data['OF'] += ooa
+                                        fielding_data['OF'] += ooa_rounded
                                     else:
-                                        fielding_data['OF'] = ooa
+                                        fielding_data['OF'] = ooa_rounded
                     return fielding_data
                 
         # IF NOT FOUND, RETURN NONE
@@ -1089,10 +1127,12 @@ class BaseballReferenceScraper:
                 positions_and_games_played[position] = games_at_position
                 # IN-GAME RATING AT
                 if position:
-                    try:                                
+                    try:
+                        drs_raw = defensive_stats['drsPosition{}'.format(position_index)]
+                        tzr_raw = defensive_stats['tzPosition{}'.format(position_index)]
                         year_defense_metrics = {
-                            'drs': int(defensive_stats['drsPosition{}'.format(position_index)]),
-                            'tzr': int(defensive_stats['tzPosition{}'.format(position_index)]),
+                            'drs': int(drs_raw) if drs_raw else None,
+                            'tzr': int(tzr_raw) if tzr_raw else None,
                         }
                     except:
                         year_defense_metrics = {'drs': 0, 'tzr': 0}
@@ -1107,12 +1147,14 @@ class BaseballReferenceScraper:
         # RE-INDEX POSITIONAL STATS
         positions_and_games_played_sorted_tuple = sorted(positions_and_games_played.items(), key=operator.itemgetter(1), reverse=True)
         for index, (position, games_played) in enumerate(positions_and_games_played_sorted_tuple, 1):
+            drs_list = [df for df in positions_and_defense[position]['drs'] if df is not None]
+            tzr_list = [tz for tz in positions_and_defense[position]['tzr'] if tz is not None]
             position_dict = {
                 f"Position{index}": position,
                 f"gPosition{index}": games_played,
                 "dWar": statistics.median(dWar_list),
-                f"drsPosition{index}": statistics.median(positions_and_defense[position]['drs']),
-                f"tzPosition{index}": statistics.median(positions_and_defense[position]['tzr']),
+                f"drsPosition{index}": statistics.median(drs_list) if len(drs_list) > 0 else None,
+                f"tzPosition{index}": statistics.median(tzr_list) if len(tzr_list) > 0 else None,
             }
             defensive_fields_dict.update(position_dict)
 
